@@ -1,6 +1,8 @@
 from test_treetime import *
 
-import_short_test()
+test_import_short()
+
+test_assign_gamma()
 
 test_GTR()
 
