@@ -1,6 +1,6 @@
 from collections import defaultdict
 import numpy as np
-from . import config as ttconf
+from . import config as ttconf, TreeTimeError, MissingDataError
 from .seq_utils import alphabets, profile_maps, alphabet_synonyms
 
 def avg_transition(W,pi, gap_index=None):
@@ -951,7 +951,12 @@ class GTR(object):
             Array of values exp(lambda(i) * t),
             where (i) - alphabet index (the eigenvalue number).
         """
-        return np.exp(self.mu * t * self.eigenvals)
+        log_val = self.mu * t * self.eigenvals
+        if any(i > 10 for i in log_val):
+            raise ValueError("Error in computing exp(Q * t): Q has positive eigenvalues or the branch length t is too large. "
+                    "This is most likely caused by incorrect input data.")
+
+        return np.exp(log_val)
 
 
     def expQt(self, t):
