@@ -1,8 +1,7 @@
 #!/usr/local/bin/python
 # -*- coding: utf-8 -*-
-from __future__ import division, print_function, absolute_import
 import numpy as np
-from .seq_utils import alphabets, profile_maps
+from .seq_utils import alphabets
 from .gtr import GTR
 
 def get_alphabet(a):
