@@ -1,8 +1,7 @@
-from __future__ import division, print_function, absolute_import
 from collections import defaultdict
 import numpy as np
 from . import config as ttconf
-from .seq_utils import alphabets, profile_maps, alphabet_synonyms, seq2array, seq2prof
+from .seq_utils import seq2array, seq2prof
 from .gtr import GTR
 from .treeanc import TreeAnc
 
@@ -87,7 +86,7 @@ class SeqGen(TreeAnc):
         from Bio.Align import MultipleSeqAlignment
 
         tmp = []
-        for n in self.tree.get_terminals():
+        for n in self.tree.find_clades():
             if n.is_terminal() or internal:
                 tmp.append(SeqRecord.SeqRecord(id=n.name, name=n.name, description='', seq=Seq.Seq(''.join(n.ancestral_sequence.astype('U')))))
 
